<?php if ( have_posts() ) {

	while ( have_posts() ) { the_post(); ?>

		<div class="single-wrapper single-blog-wrapper">

			<?php do_action( 'wpj_before_' . get_post_type() . '_single_page_content' ); ?>

			<div class="article-container">

				<?php wpj_display_blog_post_image( get_the_ID() );

				wpj_display_blog_post_title( get_the_ID() ); ?>

				<div class="article-meta">

					<?php wpj_display_blog_post_date( get_the_ID() ); ?>

					<?php wpj_display_blog_post_categories( get_the_ID(), 'category' ); ?>

				</div>

				<?php wpj_display_blog_post_content( get_the_ID() ); ?>

				<div class="article-bottom-meta">

					<!-- Tags -->
					<h6><?php _e( 'Tags', 'wpjobster' ); ?></h6>

					<?php wpj_display_blog_post_categories( get_the_ID(), 'post_tag' ); ?>

					<!-- Social Media Share Buttons -->
					<h6><?php _e( 'Share', 'wpjobster' ); ?></h6>

					<?php wpj_display_blog_post_share(); ?>

				</div>

				<div class="article-comments-section">

					<div class="article-comments-form"><?php wpj_display_blog_post_comment_form(); ?></div>

					<div class="article-comments-list"><?php wpj_display_blog_post_comments(); ?></div>

				</div>

			</div>

			<!-- Related Articles -->
			<div class="article-similar-articles">

				<h3><?php _e( 'Related articles', 'wpjobster' ); ?></h3>

				<?php wpj_display_posts_carousel( 10, 'post', true ); ?>

			</div>

		</div>

	<?php }

	wp_reset_query();

}